@@ -1,9 +1,6 @@
-__version__ = "0.0.1"
-__all__ = []
-
 from pysqa.queueadapter import QueueAdapter
 
 from ._version import get_versions
 
+__all__ = ["QueueAdapter"]
 __version__ = get_versions()["version"]
-del get_versions
